#Ryan Welch
#06 January 2017
#"Domestic Politics and the Power to Punish"
#CMPS Replication File

#set seed based on random.org (1-10000)
set.seed(4522)

library(R2jags)
library(foreign)
library(coda)
library(lattice)
library(mcmcplots)
library(Zelig)
library(MCMCpack)
library(ggplot2)
library(sm)

#Set Working Directory
setwd("C:/Users/Ryan/Documents/Research/Dissertation/Design Chapter")

#####################################################################

#District Magnitude Models

#Table 2, Model 1 Normal Prior (mean: 0; sd: 10)


#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- Intercept + DistMag*mdmh[i] + IndJud*(dnorm(1, lji[i], lji_tau[i])) + ExecLib*execrlc[i] + Democracy*(dnorm(1, uds[i], uds_tau[i])) + 
      HumanRights*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + GDP*lgdp[i] + ConflictTerm*con_term[i]
  }
  Intercept ~ dnorm (0, .01)
  DistMag ~ dnorm (0, .01)
  IndJud ~ dnorm (0, .01)
  ExecLib ~ dnorm (0, .01)
  Democracy ~ dnorm (0, .01)
  HumanRights ~ dnorm (0, .0)
  GDP ~ dnorm (0, .01)
  ConflictTerm ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("Intercept", "DistMag", "IndJud", "ExecLib", "Democracy", "HumanRights", "GDP", "ConflictTerm")

fit.dm1 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.dm1)

#Appendix, Table 14
#District Magnitude: Normal (mean: 0; sd: 5)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- Intercept + DistMag*mdmh[i] + IndJud*(dnorm(1, lji[i], lji_tau[i])) + ExecLib*execrlc[i] + Democracy*(dnorm(1, uds[i], uds_tau[i])) + 
      HumanRights*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + GDP*lgdp[i] + ConflictTerm*con_term[i]
  }
  Intercept ~ dnorm (0, .01)
  DistMag ~ dnorm (0, .04)
  IndJud ~ dnorm (0, .01)
  ExecLib ~ dnorm (0, .01)
  Democracy ~ dnorm (0, .01)
  HumanRights ~ dnorm (0, .01)
  GDP ~ dnorm (0, .01)
  ConflictTerm ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("Intercept", "DistMag", "IndJud", "ExecLib", "Democracy", "HumanRights", "GDP", "ConflictTerm")

fit.dm2 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.dm2)


#District Magnitude: Normal Prior (mean: 0; sd: 2)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- Intercept + DistMag*mdmh[i] + IndJud*(dnorm(1, lji[i], lji_tau[i])) + ExecLib*execrlc[i] + Democracy*(dnorm(1, uds[i], uds_tau[i])) + 
      HumanRights*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + GDP*lgdp[i] + ConflictTerm*con_term[i]
  }
  Intercept ~ dnorm (0, .01)
  DistMag ~ dnorm (0, .25)
  IndJud ~ dnorm (0, .01)
  ExecLib ~ dnorm (0, .01)
  Democracy ~ dnorm (0, .01)
  HumanRights ~ dnorm (0, .01)
  GDP ~ dnorm (0, .01)
  ConflictTerm ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("Intercept", "DistMag", "IndJud", "ExecLib", "Democracy", "HumanRights", "GDP", "ConflictTerm")

fit.dm3 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.dm3)



#District Magnitude: Cauchy Prior (0, 2.5)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- Intercept + DistMag*mdmh[i] + IndJud*(dnorm(1, lji[i], lji_tau[i])) + ExecLib*execrlc[i] + Democracy*(dnorm(1, uds[i], uds_tau[i])) + 
      HumanRights*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + GDP*lgdp[i] + ConflictTerm*con_term[i]
  }
  Intercept ~ dnorm (0, .01)
  DistMag ~ dt (0, .16, 1)
  IndJud ~ dnorm (0, .01)
  ExecLib ~ dnorm (0, .01)
  Democracy ~ dnorm (0, .01)
  HumanRights ~ dnorm (0, .01)
  GDP ~ dnorm (0, .01)
  ConflictTerm ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term


#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("Intercept", "DistMag", "IndJud", "ExecLib", "Democracy", "HumanRights", "GDP", "ConflictTerm")

fit.dm4 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.dm4)


########################################################################

#Closed List Models

#Read in data
 data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
 data <- data[, c("levypunishment", "cowcode", "year", "cl", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
 data <- na.omit(data)
 
 #create precisions(tau) in order to incorporate uncertainty from latent variables
 data$lji_tau <-(1/(data$lji_sd)^2)
 data$hr_latenttau <- (1/(data$hr_latentsd)^2)
 data$uds_tau <- (1/(data$uds_sd)^2)

#Table 2, Model 1 Normal Prior (mean: 0; sd: 10)
mod <- function() {
 for (i in 1:n){
   y[i] ~ dbern(p.bound[i])
   p.bound[i] <- max(0, min(1,p[i]))
   logit(p[i]) <- Xbeta[i] 
   Xbeta[i] <- b0 + b1*cl[i] + b2*(dnorm(1, lji[i], lji_tau[i])) + b3*execrlc[i] + b4*(dnorm(1, uds[i], uds_tau[i])) + 
     b5*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + b6*lgdp[i] + b7*con_term[i]
 }
 b0 ~ dnorm (0, .01)
 b1 ~ dnorm (0, .01)
 b2 ~ dnorm (0, .01)
 b3 ~ dnorm (0, .01)
 b4 ~ dnorm (0, .01)
 b5 ~ dnorm (0, .01)
 b6 ~ dnorm (0, .01)
 b7 ~ dnorm (0, .01)

}  


#defining vectors of the matrix
y <- data$levypunishment
cl <- data$cl
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "cl", "execrlc", 
            "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
            "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7")

fit.cl <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.cl)

#Table 2, Model 3: Executive Majority
  
#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "allhouse", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)
  
#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

mod <- function() {
 for (i in 1:n){
   y[i] ~ dbern(p.bound[i])
   p.bound[i] <- max(0, min(1,p[i]))
   logit(p[i]) <- Xbeta[i] 
   Xbeta[i] <- b0 + b1*allhouse[i] + b2*(dnorm(1, lji[i], lji_tau[i])) + b3*execrlc[i] + b4*(dnorm(1, uds[i], uds_tau[i])) + 
     b5*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + b6*lgdp[i] + b7*con_term[i]
 }
 b0 ~ dnorm (0, .01)
 b1 ~ dnorm (0, .01)
 b2 ~ dnorm (0, .01)
 b3 ~ dnorm (0, .01)
 b4 ~ dnorm (0, .01)
 b5 ~ dnorm (0, .01)
 b6 ~ dnorm (0, .01)
 b7 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
allhouse <- data$allhouse
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "allhouse", "execrlc", 
            "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
            "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7")

fit.em <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.em)

##################################################################

#Table 2, Model 4: Opposition Fractionalized, Normal Prior: Mean-0, SD-10

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

#Model
mod <- function() {
 for (i in 1:n){
   #lji_est ~ dnorm(lji[i], lji_tau[i])
   y[i] ~ dbern(p.bound[i])
   p.bound[i] <- max(0, min(1,p[i]))
   logit(p[i]) <- Xbeta[i] 
   Xbeta[i] <- b0 + b1*oppfrac[i] + b2*(dnorm(1, lji[i], lji_tau[i])) + b3*execrlc[i] + b4*(dnorm(1, uds[i], uds_tau[i])) + 
     b5*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + b6*lgdp[i] + b7*con_term[i]
 }
 b0 ~ dnorm (0, .01)
 b1 ~ dnorm (0, .01)
 b2 ~ dnorm (0, .01)
 b3 ~ dnorm (0, .01)
 b4 ~ dnorm (0, .01)
 b5 ~ dnorm (0, .01)
 b6 ~ dnorm (0, .01)
 b7 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "oppfrac", "execrlc", 
            "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
            "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7")

fit.of <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)

print(fit.of)

#################################################################

#Model 5: Full Model with all 4

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "cl", "allhouse", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)


#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

#Priors will only change for explanatory variable with separation: mdmh.
#All others will let data drive except con_term.  It's a control variable with separation,
#so I give it an uninformed prior.

#Normal (mean = 0, s.d. = 10)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .01)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
  
  
  
  
  
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10")

fit.full1 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.full1)



###############################################################
#Normal (mean=0, sd = 5)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .04)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10")

fit.full2 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.full2)



##############################
#Normal (mean = 0, sd = 2)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .25)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10")

fit.full3 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.full3)

#######################################
#Prior: Cauchy (0, 2.5)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dt( 0, .16, 1)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term


#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10")

fit.full4 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.full4)



###################################################
#Table 3: Densities for Betas

#looking at betas

#Model 1
#turn R2jags object into an MCMC list
fitdm.mcmc <- as.mcmc(fit.dm1)

#convert MCMC list into a matrix
fitdm.mat <- as.matrix(fitdm.mcmc)

#convert matrix into a data frame
fitdm.df <- as.data.frame(fitdm.mat)

#plot densities

fitdm.dens <- density(fitdm.df$DistMag)
plot(fitdm.dens, )
mean( min(fitdm.df$DistMag) < fitdm.df$DistMag & fitdm.df$DistMag < 0) #0.9955


#Model 2
#turn R2jags object into an MCMC list
fitcl.mcmc <- as.mcmc(fit.cl)

#convert MCMC list into a matrix
fitcl.mat <- as.matrix(fitcl.mcmc)

#convert matrix into a data frame
fitcl.df <- as.data.frame(fitcl.mat)

#plot densities

fitcl.dens <- density(fitcl.df$b1)
plot(fitcl.dens)
mean( min(fitcl.df$b1) < fitcl.df$b1 & fitcl.df$b1 < 0) #0.9735


#Model 3
#turn R2jags object into an MCMC list
fitem.mcmc <- as.mcmc(fit.em)

#convert MCMC list into a matrix
fitem.mat <- as.matrix(fitem.mcmc)

#convert matrix into a data frame
fitem.df <- as.data.frame(fitem.mat)

#plot densities

fitem.dens <- density(fitem.df$b1)
plot(fitem.dens)
mean( min(fitem.df$b1) < fitem.df$b1 & fitem.df$b1 < 0) #0.9830

#Model 4
#turn R2jags object into an MCMC list
fitof.mcmc <- as.mcmc(fit.of)

#convert MCMC list into a matrix
fitof.mat <- as.matrix(fitof.mcmc)

#convert matrix into a data frame
fitof.df <- as.data.frame(fitof.mat)

#plot densities

fitof.dens <- density(fitof.df$b1)
plot(fitof.dens)
mean( min(fitof.df$b1) < fitof.df$b1 & fitof.df$b1 < 0) #0.9995


#Model 5

#turn R2jags object into an MCMC list
fitfull.mcmc <- as.mcmc(fit.full1)

#convert MCMC list into a matrix
fitfull.mat <- as.matrix(fitfull.mcmc)

#convert matrix into a data frame
fitfull.df <- as.data.frame(fitfull.mat)

histfull.b1 <- hist(fitfull.df$b1, freq = F)
histfull.b2 <- hist(fitfull.df$b2, freq = F)
histfull.b3 <- hist(fitfull.df$b3, freq = F)
histfull.b4 <- hist(fitfull.df$b4, freq = F)


d1 <- density(fitfull.df$b1)
plot(d1)
mean( min(fitfull.df$b1) < fitfull.df$b1 & fitfull.df$b1 < 0) #.9965


d2 <- density(fitfull.df$b2)
plot(d2)
mean( min(fitfull.df$b2) < fitfull.df$b2 & fitfull.df$b2 < 0) #0.8795


d3 <- density(fitfull.df$b3)
plot(d3)
mean( min(fitfull.df$b3) < fitfull.df$b3 & fitfull.df$b3 < 0) #0.9825


d4 <- density(fitfull.df$b4)
plot(d4)
mean( min(fitfull.df$b4) < fitfull.df$b4 & fitfull.df$b4 < 0) #0.9985
###############################################################################

#Table 4: First Differences

##########################################################
###Closed List (90% CI), all covariates average, From individual (not full) model
#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "cl", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.cl)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:8] ##one column for each coefficient

#Generate vector with the simulated range of X (cl)
new.cl <- seq(min(data$cl), max(data$cl))

#Generate vectors set at desired values of the other covariates
new.lji <- rep(mean(data$lji), length(new.cl))
new.execrlc <- rep(median(data$execrlc), length(new.cl))
new.uds <- rep(mean(data$uds), length(new.cl))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.cl))
new.lgdp <- rep(mean(data$lgdp), length(new.cl))
new.con_term <- rep(median(data$con_term), length(new.cl))

constant <- rep(1, length(new.cl))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.cl, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp, new.con_term)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.cl <- exp(Xb)/(1+exp(Xb))

#make dataframe
df.punish.pp.cl <- data.frame(punish.pp.cl)

#take difference between lo and hi column and call it fd
df.punish.pp.cl$fd <- df.punish.pp.cl[,2]-df.punish.pp.cl[,1]


mean.df <- apply (df.punish.pp.cl, 2, mean)
mean.df
# X1          X2          fd 
# 0.17326529  0.02633591 -0.14692938 

#get CIs
ci.cl <- apply(df.punish.pp.cl, 2, quantile, probs=c(.05,.95))
ci.cl
# X1          X2           fd
# 5%  0.02634371 0.004101381 -0.385144085
# 95% 0.41265424 0.071752965 -0.006718087

##########################################################
###Majority (90% CI), all covariates average, From individual (not full) model

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "allhouse", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.em)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:8] ##one column for each coefficient

#Generate vector with the simulated range of X (decree)
new.allhouse <- seq(min(data$allhouse), max(data$allhouse))

#Generate vectors set at desired values of the other covariates
new.lji <- rep(mean(data$lji), length(new.allhouse))
new.execrlc <- rep(median(data$execrlc), length(new.allhouse))
new.uds <- rep(mean(data$uds), length(new.allhouse))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.allhouse))
new.lgdp <- rep(mean(data$lgdp), length(new.allhouse))
new.con_term <- rep(median(data$con_term), length(new.allhouse))

constant <- rep(1, length(new.allhouse))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.allhouse, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp, new.con_term)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.allhouse <- exp(Xb)/(1+exp(Xb))

#make dataframe
df.punish.pp.allhouse <- data.frame(punish.pp.allhouse)

#take difference between lo and hi column and call it fd
df.punish.pp.allhouse$fd <- df.punish.pp.allhouse[,2]-df.punish.pp.allhouse[,1]


mean.df <- apply (df.punish.pp.allhouse, 2, mean)
mean.df
# X1          X2          fd 
# 0.13946711  0.04682414 -0.09264297 

#get CIs
ci.allhouse <- apply(df.punish.pp.allhouse, 2, quantile, probs=c(.05,.95))
ci.allhouse
# X1         X2          fd
# 5%  0.04703028 0.01207853 -0.19435073
# 95% 0.25038617 0.10234596 -0.01434325

#Figure 1: District Magnitude Predicted Probabilities

#mdmh (90%), all covariates set to central tendency.
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.dm1)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:8] ##one column for each coefficient

#Generate vector with the simulated range of X (mdmh)
new.mdmh <- seq(min(data$mdmh), max(data$mdmh), by=0.5)

#Generate vectors set at desired values of the other covariates
new.lji <- rep(mean(data$lji), length(new.mdmh))
new.execrlc <- rep(median(data$execrlc), length(new.mdmh))
new.uds <- rep(mean(data$uds), length(new.mdmh))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.mdmh))
new.lgdp <- rep(mean(data$lgdp), length(new.mdmh))
new.con_term <- rep(median(data$con_term), length(new.mdmh))

constant <- rep(1, length(new.mdmh))

#Generate dataframe with simulated values
punish.sim <- cbind(new.con_term, new.uds, new.mdmh, new.execrlc, new.lgdp, new.hr_latentmean, new.lji, constant)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.mdmh <- exp(Xb)/(1+exp(Xb))

#Get CIs (for plotting)
punish.ci.mdmh <- apply(punish.pp.mdmh, 2, quantile, probs=c(.05,.95)) #apply function (c) to object (a), by (b: 1=row, 2=column)

#Get mean predictions over the n (from JAGS iterations) sampled values of b
mean.punish.pp.mdmh <- apply(punish.pp.mdmh, 2, mean)
mean.punish.ci.mdmh <- apply(punish.ci.mdmh, 2, quantile, probs=c(.05,.95))

#Plot mean probability against the full (simulated) range of mdmh
plot(new.mdmh, mean.punish.pp.mdmh, pch=20, main="Predicted Probability of Punishment", xlab="District Magnitude", ylab="Pr(Punish)", xlim=c(min(data$mdmh), 65), ylim=c(0,0.25))

#Add standard errors as vertical lines
segments(new.mdmh, mean.punish.ci.mdmh[1, ], new.mdmh, mean.punish.ci.mdmh[2, ], lty=1)
####################################################################3


#Figure 2: Opposition Fractionalization

#OppFrac (90%, not full model)

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.of)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:8] ##one column for each coefficient


#Generate vector with the simulated range of X 
new.oppfrac <- seq(min(data$oppfrac), max(data$oppfrac), by=0.01)

#Generate vectors set at desired values of the other covariates
new.lji <- rep(mean(data$lji), length(new.oppfrac))
new.execrlc <- rep(median(data$execrlc), length(new.oppfrac))
new.uds <- rep(mean(data$uds), length(new.oppfrac))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.oppfrac))
new.lgdp <- rep(mean(data$lgdp), length(new.oppfrac))
new.con_term <- rep(median(data$con_term), length(new.oppfrac))

constant <- rep(1, length(new.oppfrac))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.oppfrac, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp, new.con_term)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.oppfrac <- exp(Xb)/(1+exp(Xb))

#Get CIs (for plotting)
punish.ci.oppfrac <- apply(punish.pp.oppfrac, 2, quantile, probs=c(.05,.95)) #apply function (c) to object (a), by (b: 1=row, 2=column)

#Get mean predictions over the n (from JAGS iterations) sampled values of b
mean.punish.pp.oppfrac <- apply(punish.pp.oppfrac, 2, mean)
mean.punish.ci.oppfrac <- apply(punish.ci.oppfrac, 2, quantile, probs=c(.05,.95))

#Plot mean probability against the full (simulated) range of mdmh
plot(new.oppfrac, mean.punish.pp.oppfrac, pch=20, main="Predicted Probability of Punishment", xlab="Oppostion Fractionalization", ylab="Pr(Punish)", xlim=c(min(data$oppfrac), max(data$oppfrac)), ylim=c(0,0.6))

#Add standard errors as vertical lines
segments(new.oppfrac, mean.punish.ci.oppfrac[1, ], new.oppfrac, mean.punish.ci.oppfrac[2, ], lty=1)




################################################################################
#Appendix

#Table 5: Correlations with Outcome Variable
cor(data$levypunishment, data$mdmh, use="pairwise.complete.obs") #-0.1001249
cor(data$levypunishment, data$cl, use="pairwise.complete.obs") #-0.09846699
cor(data$levypunishment, data$allhouse, use="pairwise.complete.obs") #-0.1004184
cor(data$levypunishment, data$oppfrac, use="pairwise.complete.obs") #-0.2998736
cor(data$levypunishment, data$lji, use="pairwise.complete.obs") #-0.03737345
cor(data$levypunishment, data$execrlc, use="pairwise.complete.obs") #-0.01064956
cor(data$levypunishment, data$uds, use="pairwise.complete.obs") #-0.03861529
cor(data$levypunishment, data$hr_latentmean, use="pairwise.complete.obs") #-0.1533949
cor(data$levypunishment, data$lgdp, use="pairwise.complete.obs") #-0.03371021
cor(data$levypunishment, data$con_term, use="pairwise.complete.obs") #-0.1048669


#Table 6: Explanatory Variable Summary Statistics
#Done in STATA.  See NHRIPunish_Replication_07Jan2017.do

#Table 7: Control Variable Summary Statistics
#Done in STATA.  See NHRIPunish_Replication_07Jan2017.do

#Table 8: Results with Propensity Score
#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "cl", "allhouse", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term", "propensity")]
data <- na.omit(data)


#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

#Normal (mean = 0, s.d. = 10)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i] + b11*propensity[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .01)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
  b11 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term
propensity <- data$propensity

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term", "propensity")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10", "b11")

fit.prop <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.prop)
# 
# Inference for Bugs model at "C:/Users/Ryan/AppData/Local/Temp/RtmpY5fpRl/model162c22403d0.txt", fit using jags,
# 2 chains, each with 750000 iterations (first 5000 discarded), n.thin = 745
# n.sims = 2000 iterations saved
# mu.vect sd.vect    2.5%     25%    50%    75%  97.5%  Rhat n.eff
# b0        -1.985   6.819 -16.094  -6.407 -1.843  2.670 11.352 1.000  2000
# b1        -0.125   0.089  -0.335  -0.174 -0.108 -0.056 -0.009 1.003   530
# b10      -10.154   5.698 -23.820 -13.221 -9.116 -5.987 -2.104 1.001  2000
# b11        0.141   4.439  -8.198  -2.777  0.056  3.023  9.438 1.001  2000
# b2        -1.766   1.605  -5.082  -2.813 -1.726 -0.673  1.260 1.002  2000
# b3        -2.946   1.529  -6.316  -3.880 -2.832 -1.826 -0.294 1.001  2000
# b4        -6.798   2.667 -12.480  -8.440 -6.662 -5.006 -2.005 1.001  2000
# b5        -1.698   1.017  -4.265  -2.195 -1.516 -0.986 -0.233 1.004   520
# b6         0.070   0.549  -1.062  -0.276  0.084  0.438  1.079 1.001  2000
# b7        -0.600   1.004  -2.655  -1.246 -0.571  0.084  1.275 1.001  2000
# b8        -3.558   2.064  -8.255  -4.719 -3.283 -2.113 -0.098 1.003   610
# b9         0.306   0.320  -0.328   0.089  0.303  0.509  0.950 1.001  2000
# deviance  46.442   4.810  38.979  42.892 45.803 49.206 57.334 1.001  2000
# 
# For each parameter, n.eff is a crude measure of effective sample size,
# and Rhat is the potential scale reduction factor (at convergence, Rhat=1).
# 
# DIC info (using the rule, pD = var(deviance)/2)
# pD = 11.6 and DIC = 58.0
# DIC is an estimate of expected predictive error (lower deviance is better).

#Table 9: Results with Temporal Range Starting in 1993

#Temporal Span starting at 1993 rather than 1991

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "cl", "allhouse", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- data[which(data$year >= 1993), ]
data <- na.omit(data)

#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)


mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i]
    + b5*(dnorm(1, lji[i], lji_tau[i])) + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i]))
    + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + b9*lgdp[i] + b10*con_term[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .01)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term


#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10")

fit.1993 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)

print(fit.1993)

#Table 10: Other Prior Results

#See above

#Figure 3: Trace Plots

#Convergence Stats
#Diagnostics
plot(fit.full1)

traceplot(fit.full1)


#create figure
traceplot(fit.full1, mfrow = c(3, 4), ask=F) #mfrow = c(nrows, ncols)


#Figure 9: Predicted Probability from Full Model: District Magnitude

#mdmh (90%), all covariates set to central tendency.
#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "cl", "allhouse", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.full1)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:11] ##one column for each coefficient

#Generate vector with the simulated range of X (mdmh)
new.mdmh <- seq(min(data$mdmh), max(data$mdmh), by=0.5)

#Generate vectors set at desired values of the other covariates
new.cl <- rep(median(data$cl), length(new.mdmh))
new.allhouse <- rep(median(data$allhouse), length(new.mdmh))
new.oppfrac <- rep(mean(data$oppfrac), length(new.mdmh))
new.lji <- rep(mean(data$lji), length(new.mdmh))
new.execrlc <- rep(median(data$execrlc), length(new.mdmh))
new.uds <- rep(mean(data$uds), length(new.mdmh))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.mdmh))
new.lgdp <- rep(mean(data$lgdp), length(new.mdmh))
new.con_term <- rep(median(data$con_term), length(new.mdmh))

constant <- rep(1, length(new.mdmh))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.mdmh, new.con_term, new.cl, new.allhouse, new.oppfrac, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.mdmh <- exp(Xb)/(1+exp(Xb))

#Get CIs (for plotting)
punish.ci.mdmh <- apply(punish.pp.mdmh, 2, quantile, probs=c(.05,.95)) #apply function (c) to object (a), by (b: 1=row, 2=column)

#Get mean predictions over the n (from JAGS iterations) sampled values of b
mean.punish.pp.mdmh <- apply(punish.pp.mdmh, 2, mean)
mean.punish.ci.mdmh <- apply(punish.ci.mdmh, 2, quantile, probs=c(.05,.95))

#Plot mean probability against the full (simulated) range of mdmh
plot(new.mdmh, mean.punish.pp.mdmh, pch=20, main="Predicted Probability of Punishment", xlab="District Magnitude", ylab="Pr(Punish)", xlim=c(min(data$mdmh), 65), ylim=c(0,0.30))

#Add standard errors as vertical lines
segments(new.mdmh, mean.punish.ci.mdmh[1, ], new.mdmh, mean.punish.ci.mdmh[2, ], lty=1)

#Table 11: Fist Differences from Full Model

##########################################################
###Closed List (90% CI), all covariates average, from full model (5)

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.full1)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:11] ##one column for each coefficient

#Generate vector with the simulated range of X (cl)
new.cl <- seq(min(data$cl), max(data$cl))

#Generate vectors set at desired values of the other covariates
new.mdmh <- rep(mean(data$mdmh), length(new.cl))
new.allhouse <- rep(median(data$allhouse), length(new.cl))
new.oppfrac <- rep(mean(data$oppfrac, length(new.cl)))
new.lji <- rep(mean(data$lji), length(new.cl))
new.execrlc <- rep(median(data$execrlc), length(new.cl))
new.uds <- rep(mean(data$uds), length(new.cl))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.cl))
new.lgdp <- rep(mean(data$lgdp), length(new.cl))
new.con_term <- rep(median(data$con_term), length(new.cl))

constant <- rep(1, length(new.cl))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.mdmh, new.con_term, new.cl, new.allhouse, new.oppfrac, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.cl <- exp(Xb)/(1+exp(Xb))

#make dataframe
df.punish.pp.cl <- data.frame(punish.pp.cl)

#take difference between lo and hi column and call it fd
df.punish.pp.cl$fd <- df.punish.pp.cl[,2]-df.punish.pp.cl[,1]


mean.df <- apply (df.punish.pp.cl, 2, mean)
mean.df
# X1           X2           fd 
# 0.043639719  0.007237377 -0.036402343 

#get CIs
ci.cl <- apply(df.punish.pp.cl, 2, quantile, probs=c(.05,.95))
ci.cl
# X1           X2           fd
# 5%  0.0001198737 2.931696e-05 -0.192501865
# 95% 0.2148016201 3.084629e-02  0.001583414

##########################################################
###Majority (90% CI), all covariates average, frome full model

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.full1)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:11] ##one column for each coefficient

#Generate vector with the simulated range of X (decree)
new.allhouse <- seq(min(data$allhouse), max(data$allhouse))

#Generate vectors set at desired values of the other covariates
new.mdmh <- rep(mean(data$mdmh), length(new.allhouse))
new.cl <- rep(median(data$cl), length(new.allhouse))
new.oppfrac <- rep(mean(data$oppfrac), length(new.allhouse))
new.lji <- rep(mean(data$lji), length(new.allhouse))
new.execrlc <- rep(median(data$execrlc), length(new.allhouse))
new.uds <- rep(mean(data$uds), length(new.allhouse))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.allhouse))
new.lgdp <- rep(mean(data$lgdp), length(new.allhouse))
new.con_term <- rep(median(data$con_term), length(new.allhouse))

constant <- rep(1, length(new.allhouse))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.mdmh, new.con_term, new.cl, new.allhouse, new.oppfrac, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.allhouse <- exp(Xb)/(1+exp(Xb))

#make dataframe
df.punish.pp.allhouse <- data.frame(punish.pp.allhouse)

#take difference between lo and hi column and call it fd
df.punish.pp.allhouse$fd <- df.punish.pp.allhouse[,2]-df.punish.pp.allhouse[,1]


mean.df <- apply (df.punish.pp.allhouse, 2, mean)
mean.df
# X1          X2          fd 
# 0.01111531  0.00109389 -0.01002142 

#get CIs
ci.allhouse <- apply(df.punish.pp.allhouse, 2, quantile, probs=c(.05,.95))
ci.allhouse
# X1           X2            fd
# 5%  5.301817e-05 1.417431e-06 -4.326106e-02
# 95% 4.590467e-02 4.957383e-03 -2.505142e-05


#Figure 10: Predicted Probability from Full Model: Opposition Fractionalizion

#Import chains containing the coefficients from model,
#after monitoring *only* the coefficients
punish.mcmc <- as.mcmc(fit.full1)
punish.mat <- as.matrix(punish.mcmc)
b <- punish.mat[ , 1:11] ##one column for each coefficient

#Generate vector with the simulated range of X (mdmh)
new.oppfrac <- seq(min(data$oppfrac), max(data$oppfrac), by=0.01)

#Generate vectors set at desired values of the other covariates
new.cl <- rep(median(data$cl), length(new.oppfrac))
new.allhouse <- rep(median(data$allhouse), length(new.oppfrac))
new.mdmh <- rep(mean(data$mdmh), length(new.oppfrac))
new.lji <- rep(mean(data$lji), length(new.oppfrac))
new.execrlc <- rep(median(data$execrlc), length(new.oppfrac))
new.uds <- rep(mean(data$uds), length(new.oppfrac))
new.hr_latentmean <- rep(mean(data$hr_latentmean), length(new.oppfrac))
new.lgdp <- rep(mean(data$lgdp), length(new.oppfrac))
new.con_term <- rep(median(data$con_term), length(new.oppfrac))

constant <- rep(1, length(new.oppfrac))

#Generate dataframe with simulated values
punish.sim <- cbind(constant, new.mdmh, new.con_term, new.cl, new.allhouse, new.oppfrac, new.lji, new.execrlc, new.uds, new.hr_latentmean, new.lgdp)

#Multiply X by the betas from JAGS output
Xb <- t(punish.sim%*%t(b))

#Transform linear prediction to probability
punish.pp.oppfrac <- exp(Xb)/(1+exp(Xb))

#Get CIs (for plotting)
punish.ci.oppfrac <- apply(punish.pp.oppfrac, 2, quantile, probs=c(.05,.95)) #apply function (c) to object (a), by (b: 1=row, 2=column)

#Get mean predictions over the n (from JAGS iterations) sampled values of b
mean.punish.pp.oppfrac <- apply(punish.pp.oppfrac, 2, mean)
mean.punish.ci.oppfrac <- apply(punish.ci.oppfrac, 2, quantile, probs=c(.05,.95))

#Plot mean probability against the full (simulated) range of oppfrac
plot(new.oppfrac, mean.punish.pp.oppfrac, pch=20, main="Predicted Probability of Punishment", xlab="Opposition Fractionalization", ylab="Pr(Punish)", xlim=c(min(data$oppfrac), max(data$oppfrac)), ylim=c(0,0.75))

#Add standard errors as vertical lines
segments(new.oppfrac, mean.punish.ci.oppfrac[1, ], new.oppfrac, mean.punish.ci.oppfrac[2, ], lty=1)


#Table 12: Variable Distributions

#Done in STATA.  See NHRIPunish_Replication_07Jan2017.do

#Table 13: Results Including NGOs

#With Media_ai_tot
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data <- data[, c("levypunishment", "cowcode", "year", "cl", "oppfrac", "allhouse", "mdmh", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "hr_latentmean", "hr_latentsd", "lgdp", "con_term", "Media_ai_tot")]

data <- na.omit(data)
#n = 32.  Too low.

#create precisions(tau)
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)


mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i])) + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + 
      b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i])) + b9*lgdp[i] +  b10*con_term[i] +  b11*Media_ai_tot[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .01)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
  b11 ~ dnorm (0, .01)
  
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term
Media_ai_tot <- data$Media_ai_tot


#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "decree", "oppfrac", "allhouse", "mdmh", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lgdp", "cl", "lji", "lji_tau", "con_term", "Media_ai_tot")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10", "b11")

fit.ngo <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=500000, n.burnin=5000)
print(fit.ngo)

#################################################################################

#Results with Democracy Squared

#Read in data
data <- read.dta("Design_Data_17jan2016.dta", convert.factors=FALSE) 
data$uds2 <- data$uds * data$uds
data <- data[, c("levypunishment", "cowcode", "year", "mdmh", "cl", "allhouse", "oppfrac", "lji", "lji_sd", "execrlc", "uds", "uds_sd", "uds2", "hr_latentmean", "hr_latentsd", "lgdp", "con_term")]
data <- na.omit(data)


#create precisions(tau) in order to incorporate uncertainty from latent variables
data$lji_tau <-(1/(data$lji_sd)^2)
data$hr_latenttau <- (1/(data$hr_latentsd)^2)
data$uds_tau <- (1/(data$uds_sd)^2)

#Normal (mean = 0, s.d. = 10)

mod <- function() {
  for (i in 1:n){
    y[i] ~ dbern(p.bound[i])
    p.bound[i] <- max(0, min(1,p[i]))
    logit(p[i]) <- Xbeta[i] 
    Xbeta[i] <- b0 + b1*mdmh[i] + b2*cl[i] + b3*allhouse[i] + b4*oppfrac[i] + b5*(dnorm(1, lji[i], lji_tau[i]))
    + b6*execrlc[i] + b7*(dnorm(1, uds[i], uds_tau[i])) + b8*(dnorm(1, hr_latentmean[i], hr_latenttau[i]))
    + b9*lgdp[i] + b10*con_term[i] + b11*uds2[i]
  }
  b0 ~ dnorm (0, .01)
  b1 ~ dnorm (0, .01)
  b2 ~ dnorm (0, .01)
  b3 ~ dnorm (0, .01)
  b4 ~ dnorm (0, .01)
  b5 ~ dnorm (0, .01)
  b6 ~ dnorm (0, .01)
  b7 ~ dnorm (0, .01)
  b8 ~ dnorm (0, .01)
  b9 ~ dnorm (0, .01)
  b10 ~ dnorm (0, .01)
  b11 ~ dnorm (0, .01)
}  


#defining vectors of the matrix
y <- data$levypunishment
oppfrac <- data$oppfrac
allhouse <- data$allhouse
cl <- data$cl
mdmh <- data$mdmh
lji <- data$lji
lji_tau <- data$lji_tau
execrlc <- data$execrlc
uds <- data$uds
uds_tau <- data$uds_tau
hr_latentmean <- data$hr_latentmean
hr_latenttau <- data$hr_latenttau
lgdp <- data$lgdp
con_term <- data$con_term
uds2 <- data$uds2

#Define data summaries
n <- length(y)

#Fit the model in JAGS

dat <- list ("n", "y", "mdmh", "cl", "allhouse", "oppfrac", "execrlc", 
             "uds", "uds_tau", "hr_latentmean", "hr_latenttau", "lji",
             "lji_tau", "lgdp", "con_term", "uds2")

params <- c ("b0", "b1", "b2", "b3", "b4", "b5", "b6", "b7", "b8", "b9", "b10", "b11")

fit.dem2 <- jags(data=dat, inits = NULL, parameters.to.save=params, model.file=mod, n.chains=2, n.iter=750000, n.burnin=5000)
# 
# print(fit.dem2)
# 
# Inference for Bugs model at "C:/Users/Ryan/AppData/Local/Temp/RtmpUhWaVD/model2f7068a018ec.txt", fit using jags,
# 2 chains, each with 750000 iterations (first 5000 discarded), n.thin = 745
# n.sims = 2000 iterations saved
# mu.vect sd.vect    2.5%     25%    50%    75%  97.5%  Rhat n.eff
# b0        -2.395   6.890 -15.749  -6.906 -2.491  2.154 11.042 1.001  2000
# b1        -0.121   0.083  -0.319  -0.166 -0.105 -0.058 -0.008 1.002   980
# b10      -10.428   5.811 -23.875 -13.810 -9.429 -6.079 -1.968 1.001  2000
# b11       -4.555   2.857 -11.175  -6.234 -4.220 -2.556  0.034 1.006   370
# b2        -2.221   1.698  -5.764  -3.291 -2.171 -1.055  0.964 1.001  2000
# b3        -2.700   1.570  -6.148  -3.632 -2.577 -1.672  0.132 1.001  1500
# b4        -6.913   2.500 -12.378  -8.441 -6.720 -5.197 -2.492 1.002  1300
# b5         0.437   1.602  -2.761  -0.552  0.396  1.429  3.729 1.003  1600
# b6        -0.180   0.584  -1.390  -0.546 -0.173  0.216  0.911 1.002  1100
# b7         1.194   1.551  -1.578   0.094  1.108  2.127  4.496 1.005   550
# b8        -3.177   2.287  -8.419  -4.506 -2.981 -1.576  0.751 1.002  2000
# b9         0.388   0.309  -0.208   0.172  0.389  0.592  0.984 1.001  2000
# deviance  44.261   4.935  36.587  40.718 43.537 47.145 55.234 1.001  2000
# 
# For each parameter, n.eff is a crude measure of effective sample size,
# and Rhat is the potential scale reduction factor (at convergence, Rhat=1).
# 
# DIC info (using the rule, pD = var(deviance)/2)
# pD = 12.2 and DIC = 56.4
# DIC is an estimate of expected predictive error (lower deviance is better).